#region usings
using System;
using System.ComponentModel.Composition;

using VVVV.PluginInterfaces.V1;
using VVVV.PluginInterfaces.V2;
using VVVV.Utils.VColor;
using VVVV.Utils.VMath;
using SlimDX;

using VVVV.Core.Logging;
#endregion usings

namespace VVVV.Nodes
{
	[PluginInfoAttribute(Name = "Split", Category = "Exhibit", Version = "live")]
	public class SplitExhibitNode : IPluginEvaluate
	{
		
		[Input("Input")]
		ISpread<Exhibit> FExhibitIn;
		
		[Output("Id")]
		ISpread<int> FIdOut;
		
		[Output("Color")]
		ISpread<RGBAColor> FColorOut;
		
		[Output("Words")]
		ISpread<ISpread<string>> FWordsOut;
		
		[Output("Transformation")]
		ISpread<Matrix> FTransformOut;
		
		// Gets called every frame by vvvv if one of our outputs should
		// provide some data for a node downstream.
		public void Evaluate(int spreadMax)
		{
			// Calculate the maximum slice count
			//not really necessary - we only have one pin - but good style: 
			spreadMax = SpreadUtils.SpreadMax(FExhibitIn); 
			
			FColorOut.SliceCount = spreadMax;
			FWordsOut.SliceCount = spreadMax;
			FTransformOut.SliceCount = spreadMax;
			FIdOut.SliceCount = spreadMax;
			
			for (int i = 0; i < spreadMax; i++)
			{
				var exhibit = FExhibitIn[i];
				FIdOut[i] = exhibit.ID;
				FColorOut[i] = exhibit.Color;
				FWordsOut[i] = exhibit.Words;
				FTransformOut[i] = exhibit.Transformation;
			}
		}	
	}
}
